@@ -7,7 +7,7 @@ use strict;
 
 package XML::Compile::Schema::Translate;
 use vars '$VERSION';
-$VERSION = '0.58';
+$VERSION = '0.59';
 
 use Log::Report 'xml-compile', syntax => 'SHORT';
 use List::Util  'first';
@@ -449,12 +449,13 @@ sub element($)
     my $fullname = pack_type $self->{tns}, $name;
 
     # detect recursion
-    if(exists $self->{nest}{$fullname})
-    {   my $outer = \$self->{nest}{$fullname};
-#warn "Recursion detected for $fullname";
+    my $nodeid = $$node;  # the internal SCALAR value; the C struct
+    if(exists $self->{nest}{$nodeid})
+    {   my $outer = \$self->{nest}{$nodeid};
+#warn "Recursion detected for $nodeid";
         return sub { $$outer->(@_) };
     }
-    $self->{nest}{$fullname} = undef;
+    $self->{nest}{$nodeid} = undef;
 
     my $where    = $tree->path. "#el($name)";
     my $form     = $node->getAttribute('form');
@@ -519,15 +520,15 @@ sub element($)
     {   $r = $self->make(simple_element => $where, $tag, $st);
     }
 
-    # this must look very silly to you... however, this is resolving
-    # recursive schemas: this way nested use of the same element
-    # definition will catch the code reference of the outer definition.
-    $self->{nest}{$fullname}
-      = ($before || $replace || $after)
+    my $do = ($before || $replace || $after)
       ? $self->make(hook => $where, $r, $tag, $before, $replace, $after)
       : $r;
 
-    delete $self->{nest}{$fullname};  # clean the outer definition
+    # this must look very silly to you... however, this is resolving
+    # recursive schemas: this way nested use of the same element
+    # definition will catch the code reference of the outer definition.
+    $self->{nest}{$nodeid} = $do;
+    delete $self->{nest}{$nodeid};  # clean the outer definition
 }
 
 sub particle($)
